﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace Demo20140608
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            this.Loaded += MainWindow_Loaded;
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            /* 注册点击事件 */
            Circle.MouseLeftButtonDown += UIElement_MouseLeftButtonDown;
            Square.MouseLeftButtonDown += UIElement_MouseLeftButtonDown;
        }

        /// <summary>
        /// 鼠标点击事件方法
        /// </summary>
        void UIElement_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            if (sender is UIElement)
            {
                MoveToRight(sender as UIElement, 100);
            }
        }

        /// <summary>
        /// 将某ui元素往右移动
        /// <param name="uiElement">需要移动的ui元素</param>
        /// <param name="distance">移动距离</param>
        /// </summary>
        void MoveToRight(UIElement uiElement, double distance)
        {
            double start = Canvas.GetLeft(uiElement);
            double end = start + distance;

            DoubleAnimation ani = new DoubleAnimation();
            ani.From = start;
            ani.To = end;
            ani.Duration = new Duration(TimeSpan.FromSeconds(0.25));
            ani.Completed += ani_Completed;

            /* !!! 附加属性Storyboard.Target，用于指定执行动画的UI对象 !!! */
            Storyboard.SetTarget(ani, uiElement);

            /* 启动动画 */
            uiElement.BeginAnimation(Canvas.LeftProperty, ani);
        }

        /// <summary>
        /// 动画完成事件方法
        /// </summary>
        void ani_Completed(object sender, EventArgs e)
        {
            if (sender is AnimationClock)
            {
                AnimationTimeline timeline = (sender as AnimationClock).Timeline;

                /* !!! 通过附加属性把UI对象取回 !!! */
                object uiElement = Storyboard.GetTarget(timeline);
            }




            if (sender is AnimationClock)
            {
                AnimationTimeline timeline = (sender as AnimationClock).Timeline;

                /* !!! 通过附加属性把UI对象取回 !!! */
                object uiElement = Storyboard.GetTarget(timeline);
                if (uiElement is Shape)
                {
                    Random random = new Random();
                    byte r = (byte)random.Next(0, 255);
                    byte g = (byte)random.Next(0, 255);
                    byte b = (byte)random.Next(0, 255);

                    Shape shape = uiElement as Shape;

                    /* 将ui元素变色 */
                    shape.Fill = new SolidColorBrush(Color.FromRgb(r, g, b));

                    /* 把ui元素的类型显示在窗口的title上 */
                    this.Title = string.Format("{0} is moved to right :)", shape.Name);
                }
            }
        }
    }
}
